@@ -56,6 +56,7 @@ import testtools
 from nova.api.openstack import wsgi_app
 from nova.compute import rpcapi as compute_rpcapi
 from nova import context
+import nova.crypto
 from nova.db.main import api as db_api
 from nova import exception
 from nova import objects
@@ -192,6 +193,7 @@ class TestCase(base.BaseTestCase):
         self._service_fixture_count = collections.defaultdict(int)
 
         self.useFixture(nova_fixtures.OpenStackSDKFixture())
+        self.useFixture(nova_fixtures.IsolatedGreenPoolFixture(self.id()))
 
         self.useFixture(log_fixture.get_logging_handle_error_fixture())
 
@@ -324,6 +326,9 @@ class TestCase(base.BaseTestCase):
         # the currently running test to fail.
         self.useFixture(nova_fixtures.GreenThreadPoolShutdownWait())
 
+        # Reset the global key manager
+        nova.crypto._KEYMGR = None
+
     def _setup_cells(self):
         """Setup a normal cellsv2 environment.
 
@@ -417,6 +422,12 @@ class TestCase(base.BaseTestCase):
         for k, v in kw.items():
             CONF.set_override(k, v, group)
 
+    def reset_flags(self, *k, **kw):
+        """Reset flag variables for a test."""
+        group = kw.pop('group')
+        for flag in k:
+            CONF.clear_override(flag, group)
+
     def enforce_fk_constraints(self, engine=None):
         if engine is None:
             engine = db_api.get_engine()
@@ -443,6 +454,8 @@ class TestCase(base.BaseTestCase):
             ctxt = context.get_context()
             cell_name = cell_name or CELL1_NAME
             cell = self.cell_mappings[cell_name]
+            svc = self.useFixture(
+                nova_fixtures.ServiceFixture(name, host, cell=cell, **kwargs))
             if (host or name) not in self.host_mappings:
                 # NOTE(gibi): If the HostMapping does not exists then this is
                 # the first start of the service so we create the mapping.
@@ -451,8 +464,19 @@ class TestCase(base.BaseTestCase):
                                          cell_mapping=cell)
                 hm.create()
                 self.host_mappings[hm.host] = hm
-        svc = self.useFixture(
-            nova_fixtures.ServiceFixture(name, host, cell=cell, **kwargs))
+
+                # NOTE(jlejeune): update the compute node's mapped field
+                # like it's done in _check_and_create_node_host_mappings()
+                # function.
+                with context.target_cell(ctxt, cell) as cctxt:
+                    node = objects.ComputeNode.get_by_service_id(
+                        context=cctxt,
+                        service_id=svc.service.service_ref.id)
+                    node.mapped = 1
+                    node.save()
+        else:
+            svc = self.useFixture(
+                nova_fixtures.ServiceFixture(name, host, cell=cell, **kwargs))
 
         # Keep track of how many instances of this service are running.
         self._service_fixture_count[name] += 1
@@ -734,16 +758,20 @@ class SubclassSignatureTestCase(testtools.TestCase, metaclass=abc.ABCMeta):
         # getmembers returns all members, including members inherited from
         # the base class. It's redundant for us to test these, but as
         # they'll always pass it's not worth the complexity to filter them out.
-        for (name, method) in inspect.getmembers(cls, inspect.ismethod):
+        for (name, method) in inspect.getmembers(cls, inspect.isfunction):
             # Subclass __init__ methods can usually be legitimately different
             if name == '__init__':
                 continue
 
+            # Skip subclass private functions
+            if name.startswith('_'):
+                continue
+
             while hasattr(method, '__wrapped__'):
                 # This is a wrapped function. The signature we're going to
                 # see here is that of the wrapper, which is almost certainly
                 # going to involve varargs and kwargs, and therefore is
-                # unlikely to be what we want. If the wrapper manupulates the
+                # unlikely to be what we want. If the wrapper manipulates the
                 # arguments taken by the wrapped function, the wrapped function
                 # isn't what we want either. In that case we're just stumped:
                 # if it ever comes up, add more knobs here to work round it (or
@@ -828,10 +856,10 @@ class MatchType(object):
         self.wanttype = wanttype
 
     def __eq__(self, other):
-        return type(other) == self.wanttype
+        return type(other) is self.wanttype
 
     def __ne__(self, other):
-        return type(other) != self.wanttype
+        return type(other) is not self.wanttype
 
     def __repr__(self):
         return "<MatchType:" + str(self.wanttype) + ">"
